# JoinBoost: In-Database Factorized Tree-Models

[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)

JoinBoost the first In-DB factorized learning system for tree-based models. 

The technical report is in the /technical.

## Reproducibility

We note that some feataures discussed in the paper (e.g., inter-query parallelism, DP) are not implemented in the main codes for reliability concerns.
To reproduce the experiment results from the paper, we include the prototype codes for JoinBoost under /proto folder, which includes the JoinBoost codes and Jupyer Notebook to train models over Favorita.
The Favorita dataset is too large to store in Github. They can be found in dropbox.

